summaryrefslogtreecommitdiffstats
path: root/kapptemplate/kpartplugin/plugin_app.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kapptemplate/kpartplugin/plugin_app.cpp')
-rw-r--r--kapptemplate/kpartplugin/plugin_app.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/kapptemplate/kpartplugin/plugin_app.cpp b/kapptemplate/kpartplugin/plugin_app.cpp
index 0ec7a273..c6a27fb8 100644
--- a/kapptemplate/kpartplugin/plugin_app.cpp
+++ b/kapptemplate/kpartplugin/plugin_app.cpp
@@ -13,9 +13,9 @@ typedef KGenericFactory<Plugin${APP_NAME}> ${APP_NAME}Factory;
K_EXPORT_COMPONENT_FACTORY( lib${APP_NAME_LC}plugin,
${APP_NAME}Factory( "${APP_NAME_LC}" ) );
-Plugin${APP_NAME}::Plugin${APP_NAME}( TQObject* parent, const char* name,
+Plugin${APP_NAME}::Plugin${APP_NAME}( TQObject* tqparent, const char* name,
const TQStringList & /*args*/ )
- : Plugin( parent, name )
+ : Plugin( tqparent, name )
{
// Instantiate all of your actions here. These will appear in
// Konqueror's menu and toolbars.
@@ -33,7 +33,7 @@ void Plugin${APP_NAME}::slotAction()
// This plugin assumes KHTMLPart. If your plugin can handle more
// than this or a different Part than this, simply delete or
// change the following block.
- if ( !parent()->inherits("KHTMLPart") )
+ if ( !tqparent()->inherits("KHTMLPart") )
{
TQString title( i18n( "Cannot Translate Source" ) );
TQString text( i18n( "You cannot translate anything except web pages "
@@ -43,9 +43,9 @@ void Plugin${APP_NAME}::slotAction()
return;
}
// Get a handle on our parent so we may get the necessary data for
// processing
- KHTMLPart *part = dynamic_cast<KHTMLPart *>(parent());
+ KHTMLPart *part = dynamic_cast<KHTMLPart *>(tqparent());
// This plugin only uses the URL. You may use whatever data you
// need.
@@ -43,9 +43,9 @@ void Plugin${APP_NAME}::slotAction()
return;
}
- // Get a handle on our parent so we may get the necessary data for
+ // Get a handle on our tqparent so we may get the necessary data for
// processing